@@ -1,72 +1,73 @@
 'use strict';
 
-var anymatch = require('./');
-var assert = require('assert');
-var path = require('path');
+let anymatch = require('./');
+let assert = require('assert');
+let path = require('path');
 
-describe('anymatch', function() {
+describe('anymatch', () => {
   var matchers = [
     'path/to/file.js',
     'path/anyjs/**/*.js',
     /foo.js$/,
-    function(string) {
-      return string.indexOf('/bar') !== -1 && string.length > 10;
-    }
+    (string => string.indexOf('/bar') !== -1 && string.length > 10)
   ];
-  it('should resolve string matchers', function() {
-    assert.equal(true, anymatch(matchers, 'path/to/file.js'));
-    assert.equal(true, anymatch(matchers[0], 'path/to/file.js'));
-    assert.equal(false, anymatch(matchers[0], 'bar.js'));
+  it('should resolve string matchers', () => {
+    assert(anymatch(matchers, 'path/to/file.js'));
+    assert(anymatch(matchers[0], 'path/to/file.js'));
+    assert(!anymatch(matchers[0], 'bar.js'));
   });
-  it('should resolve glob matchers', function() {
+  it('should resolve glob matchers', () => {
     assert.equal(true, anymatch(matchers, 'path/anyjs/baz.js'));
     assert.equal(true, anymatch(matchers[1], 'path/anyjs/baz.js'));
     assert.equal(false, anymatch(matchers[1], 'bar.js'));
   });
-  it('should resolve regexp matchers', function() {
+  it('should resolve regexp matchers', () => {
     assert.equal(true, anymatch(matchers, 'path/to/foo.js'));
     assert.equal(true, anymatch(matchers[2], 'path/to/foo.js'));
     assert.equal(false, anymatch(matchers[2], 'bar.js'));
   });
-  it('should resolve function matchers', function() {
+  it('should resolve function matchers', () => {
     assert.equal(true, anymatch(matchers, 'path/to/bar.js'));
     assert.equal(true, anymatch(matchers[3], 'path/to/bar.js'));
     assert.equal(false, anymatch(matchers[3], 'bar.js'));
   });
-  it('should return false for unmatched strings', function() {
+  it('should return false for unmatched strings', () => {
     assert.equal(false, anymatch(matchers, 'bar.js'));
   });
-  it('should ignore improperly typed matchers', function() {
+  it('should ignore improperly typed matchers', () => {
     var emptyObj = {};
-    assert.equal(false, anymatch(emptyObj, emptyObj));
-    assert.equal(false, anymatch(Infinity, Infinity));
+    assert.equal(false, anymatch(emptyObj, ''));
+    assert.equal(false, anymatch(Infinity, ''));
   });
 
-  describe('with returnIndex = true', function() {
-    it('should return the array index of first positive matcher', function() {
+  describe('with returnIndex = true', () => {
+    it('should return the array index of first positive matcher', () => {
       var result = anymatch(matchers, 'foo.js', true);
       assert.equal(result, 2);
     });
-    it('should return 0 if provided non-array matcher', function() {
+    it('should return 0 if provided non-array matcher', () => {
       var result = anymatch(matchers[2], 'foo.js', true);
       assert.equal(result, 0);
     });
-    it('should return -1 if no match', function() {
+    it('should return -1 if no match', () => {
       var result = anymatch(matchers, 'bar.js', true);
       assert.equal(result, -1);
     });
   });
 
-  describe('curried matching function', function() {
-    var matchFn = anymatch(matchers);
-    it('should resolve matchers', function() {
+  describe('curried matching function', () => {
+    var matchFn;
+    before(() => {
+      matchFn = anymatch(matchers);
+    });
+    it('should resolve matchers', () => {
       assert.equal(true, matchFn('path/to/file.js'));
       assert.equal(true, matchFn('path/anyjs/baz.js'));
       assert.equal(true, matchFn('path/to/foo.js'));
       assert.equal(true, matchFn('path/to/bar.js'));
       assert.equal(false, matchFn('bar.js'));
     });
-    it('should be usable as an Array.prototype.filter callback', function() {
+    it('should be usable as an Array.prototype.filter callback', () => {
       var arr = [
         'path/to/file.js',
         'path/anyjs/baz.js',
@@ -79,7 +80,7 @@ describe('anymatch', function() {
       expected.splice(arr.indexOf('bar.js'), 1);
       assert.deepEqual(arr.filter(matchFn), expected);
     });
-    it('should bind individual criterion', function() {
+    it('should bind individual criterion', () => {
       assert(anymatch(matchers[0])('path/to/file.js'));
       assert(!anymatch(matchers[0])('path/to/other.js'));
       assert(anymatch(matchers[1])('path/anyjs/baz.js'));
@@ -91,96 +92,91 @@ describe('anymatch', function() {
     });
   });
 
-  describe('using matcher subsets', function() {
-    it('should skip matchers before the startIndex', function() {
-      assert(anymatch(matchers, 'path/to/file.js', false));
-      assert(!anymatch(matchers, 'path/to/file.js', false, 1));
+  describe('extra args', () => {
+    it('should not allow no args', () => {
+      assert.throws(() => anymatch());
+    })
+    it('should not allow bad testString', () => {
+      assert.throws(() => anymatch(matchers, {path: 'path/to/bar.js'}));
     });
-    it('should skip matchers after and including the endIndex', function() {
-      assert(anymatch(matchers, 'path/to/bars.js', false));
-      assert(!anymatch(matchers, 'path/to/bars.js', false, 0, 3));
-      assert(!anymatch(matchers, 'foo.js', false, 0, 1));
+    it('should allow string to be passed as first member of an array', () => {
+      assert.doesNotThrow(() => anymatch(matchers, ['path/to/bar.js']));
     });
-  });
 
-  describe('extra args', function() {
-    it('should allow string to be passed as first member of an array', function() {
-      assert(anymatch(matchers, ['path/to/bar.js']));
-    });
-    it('should pass extra args to function matchers', function() {
-      matchers.push(function(string, arg1, arg2) { return arg1 || arg2; });
-      assert(!anymatch(matchers, 'bar.js'), 1);
-      assert(!anymatch(matchers, ['bar.js', 0]), 2);
-      assert(anymatch(matchers, ['bar.js', true]), 3);
-      assert(anymatch(matchers, ['bar.js', 0, true]), 4);
+    it('should pass extra args to function matchers', () => {
+      matchers.push((string, arg1, arg2) => arg1 || arg2);
+      assert(!anymatch(matchers, 'bar.js'), '1');
+      assert(!anymatch(matchers, ['bar.js', 0]), '2');
+      assert(anymatch(matchers, ['bar.js', true]), '3');
+      assert(anymatch(matchers, ['bar.js', 0, true]), '4');
       // with returnIndex
-      assert.equal(anymatch(matchers, ['bar.js', 1], true), 4, 5);
+      assert.equal(anymatch(matchers, ['bar.js', 1], true), 4, '5');
       // curried versions
       var matchFn1 = anymatch(matchers);
       var matchFn2 = anymatch(matchers[4]);
-      assert(!matchFn1(['bar.js', 0]), 6);
-      assert(!matchFn2(['bar.js', 0]), 7);
-      assert(matchFn1(['bar.js', true]), 8);
-      assert(matchFn2(['bar.js', true]), 9);
-      assert(matchFn1(['bar.js', 0, true]), 10);
-      assert(matchFn2(['bar.js', 0, true]), 11);
+      assert(!matchFn1(['bar.js', 0]), '6');
+      assert(!matchFn2(['bar.js', 0]), '7');
+      assert(matchFn1(['bar.js', true]), '8');
+      assert(matchFn2(['bar.js', true]), '9');
+      assert(matchFn1(['bar.js', 0, true]), '10');
+      assert(matchFn2(['bar.js', 0, true]), '11');
       // curried with returnIndex
-      assert.equal(matchFn1(['bar.js', 1], true), 4, 12);
-      assert.equal(matchFn2(['bar.js', 1], true), 0, 13);
-      assert.equal(matchFn1(['bar.js', 0], true), -1, 14);
-      assert.equal(matchFn2(['bar.js', 0], true), -1, 15);
+      assert.equal(matchFn1(['bar.js', 1], true), 4, '12');
+      assert.equal(matchFn2(['bar.js', 1], true), 0, '13');
+      assert.equal(matchFn1(['bar.js', 0], true), -1, '14');
+      assert.equal(matchFn2(['bar.js', 0], true), -1, '15');
       matchers.pop();
     });
   });
 
-  describe('glob negation', function() {
+  describe('glob negation', () => {
     after(matchers.splice.bind(matchers, 4, 2));
 
-    it('should respect negated globs included in a matcher array', function() {
+    it('should respect negated globs included in a matcher array', () => {
       assert(anymatch(matchers, 'path/anyjs/no/no.js'), 'matches existing glob');
       matchers.push('!path/anyjs/no/*.js');
       assert(!anymatch(matchers, 'path/anyjs/no/no.js'), 'should be negated');
       assert(!anymatch(matchers)('path/anyjs/no/no.js'), 'should be negated (curried)');
     });
-    it('should not break returnIndex option', function() {
+    it('should not break returnIndex option', () => {
       assert.equal(anymatch(matchers, 'path/anyjs/yes.js', true), 1);
       assert.equal(anymatch(matchers)('path/anyjs/yes.js', true), 1);
       assert.equal(anymatch(matchers, 'path/anyjs/no/no.js', true), -1);
       assert.equal(anymatch(matchers)('path/anyjs/no/no.js', true), -1);
     });
-    it('should allow negated globs to negate non-glob matchers', function() {
+    it('should allow negated globs to negate non-glob matchers', () => {
       assert.equal(anymatch(matchers, 'path/to/bar.js', true), 3);
       matchers.push('!path/to/bar.*');
       assert(!anymatch(matchers, 'path/to/bar.js'));
     });
   });
 
-  describe('windows paths', function() {
+  describe('windows paths', () => {
     var origSep = path.sep;
-    before(function() {
+    before(() => {
       path.sep = '\\';
     });
-    after(function() {
+    after(() => {
       path.sep = origSep;
     });
 
-    it('should resolve backslashes against string matchers', function() {
+    it('should resolve backslashes against string matchers', () => {
       assert(anymatch(matchers, 'path\\to\\file.js'));
       assert(anymatch(matchers)('path\\to\\file.js'));
     });
-    it('should resolve backslashes against glob matchers', function() {
+    it('should resolve backslashes against glob matchers', () => {
       assert(anymatch(matchers, 'path\\anyjs\\file.js'));
       assert(anymatch(matchers)('path\\anyjs\\file.js'));
     });
-    it('should resolve backslashes against regex matchers', function() {
+    it('should resolve backslashes against regex matchers', () => {
       assert(anymatch(/path\/to\/file\.js/, 'path\\to\\file.js'));
       assert(anymatch(/path\/to\/file\.js/)('path\\to\\file.js'));
     });
-    it('should resolve backslashes against function matchers', function() {
+    it('should resolve backslashes against function matchers', () => {
       assert(anymatch(matchers, 'path\\to\\bar.js'));
       assert(anymatch(matchers)('path\\to\\bar.js'));
     });
-    it('should still correctly handle forward-slash paths', function() {
+    it('should still correctly handle forward-slash paths', () => {
       assert(anymatch(matchers, 'path/to/file.js'));
       assert(anymatch(matchers)('path/to/file.js'));
       assert(!anymatch(matchers, 'path/no/no.js'));
